@@ -2,13 +2,10 @@
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
-"""Command line wrapper for the multiple alignment program Clustal W.
-"""
+"""Command line wrapper for the multiple alignment program Clustal W."""
 
 from __future__ import print_function
 
-__docformat__ = "restructuredtext en"  # Don't just use plain text in epydoc API pages!
-
 import os
 from Bio.Application import _Option, _Switch, AbstractCommandline
 
@@ -40,6 +37,7 @@ class ClustalwCommandline(AbstractCommandline):
 
     Last checked against versions: 1.83 and 2.1
     """
+
     # TODO - Should we default to cmd="clustalw2" now?
     def __init__(self, cmd="clustalw", **kwargs):
         self.parameters = \
@@ -330,12 +328,6 @@ class ClustalwCommandline(AbstractCommandline):
         AbstractCommandline.__init__(self, cmd, **kwargs)
 
 
-def _test():
-    """Run the module's doctests (PRIVATE)."""
-    print("Running ClustalW doctests...")
-    import doctest
-    doctest.testmod()
-    print("Done")
-
 if __name__ == "__main__":
-    _test()
+    from Bio._utils import run_doctest
+    run_doctest()
