@@ -14,9 +14,6 @@ from __future__ import print_function
 from Bio.Blast import Record
 import xml.sax
 from xml.sax.handler import ContentHandler
-from functools import reduce
-
-__docformat__ = "restructuredtext en"
 
 
 class _XMLparser(ContentHandler):
@@ -26,10 +23,13 @@ class _XMLparser(ContentHandler):
 
     Redefine the methods startElement, characters and endElement.
     """
+
     def __init__(self, debug=0):
         """Constructor.
 
-        debug - integer, amount of debug information to print
+        Arguments:
+         - debug - integer, amount of debug information to print
+
         """
         self._tag = []
         self._value = ''
@@ -39,7 +39,9 @@ class _XMLparser(ContentHandler):
     def _secure_name(self, name):
         """Removes 'dangerous' from tag names.
 
-        name -- name to be 'secured'
+        Arguments:
+         - name -- name to be 'secured'
+
         """
         # Replace '-' with '_' in XML tag names
         return name.replace('-', '_')
@@ -49,9 +51,10 @@ class _XMLparser(ContentHandler):
 
         No real need of attr, BLAST DTD doesn't use them
 
-        name -- name of the tag
+        Arguments:
+         - name -- name of the tag
+         - attr -- tag attributes
 
-        attr -- tag attributes
         """
         self._tag.append(name)
 
@@ -61,7 +64,7 @@ class _XMLparser(ContentHandler):
         # Note could use try / except AttributeError
         # BUT I found often triggered by nested errors...
         if hasattr(self, method):
-            eval("self.%s()" % method)
+            getattr(self, method)()
             if self._debug > 4:
                 print("NCBIXML: Parsed:  " + method)
         elif self._debug > 3:
@@ -80,14 +83,18 @@ class _XMLparser(ContentHandler):
     def characters(self, ch):
         """Found some text.
 
-        ch -- characters read
+        Arguments:
+         - ch -- characters read
+
         """
         self._value += ch  # You don't ever get the whole string
 
     def endElement(self, name):
         """Found XML end tag.
 
-        name -- tag name
+        Arguments:
+         - name -- tag name
+
         """
         # DON'T strip any white space, we may need it e.g. the hsp-midline
 
@@ -96,7 +103,7 @@ class _XMLparser(ContentHandler):
         # Note could use try / except AttributeError
         # BUT I found often triggered by nested errors...
         if hasattr(self, method):
-            eval("self.%s()" % method)
+            getattr(self, method)()
             if self._debug > 2:
                 print("NCBIXML: Parsed:  %s %s" % (method, self._value))
         elif self._debug > 1:
@@ -118,14 +125,18 @@ class BlastParser(_XMLparser):
     You are expected to use this via the parse or read functions.
 
     All XML 'action' methods are private methods and may be:
-        - ``_start_TAG`` called when the start tag is found
-        - ``_end_TAG`` called when the end tag is found
+
+    - ``_start_TAG`` called when the start tag is found
+    - ``_end_TAG`` called when the end tag is found
+
     """
 
     def __init__(self, debug=0):
         """Constructor.
 
-        debug - integer, amount of debug information to print
+        Arguments:
+         - debug - integer, amount of debug information to print
+
         """
         # Calling superclass method
         _XMLparser.__init__(self, debug)
@@ -164,7 +175,7 @@ class BlastParser(_XMLparser):
         # These are required for "old" pre 2.2.14 files
         # where only <BlastOutput_query-ID>, <BlastOutput_query-def>
         # and <BlastOutput_query-len> were used.  Now they
-        # are suplemented/replaced by <Iteration_query-ID>,
+        # are supplemented/replaced by <Iteration_query-ID>,
         # <Iteration_query-def> and <Iteration_query-len>
         if not hasattr(self._blast, "query") \
         or not self._blast.query:
@@ -218,7 +229,7 @@ class BlastParser(_XMLparser):
         self._header.application = self._value.upper()
 
     def _end_BlastOutput_version(self):
-        """version number and date of the BLAST engine.
+        """Version number and date of the BLAST engine.
 
         e.g. "BLASTX 2.2.12 [Aug-07-2005]" but there can also be
         variants like "BLASTP 2.2.18+" without the date.
@@ -241,21 +252,21 @@ class BlastParser(_XMLparser):
                 self._header.date = parts[2]
 
     def _end_BlastOutput_reference(self):
-        """a reference to the article describing the algorithm (PRIVATE).
+        """A reference to the article describing the algorithm (PRIVATE).
 
         Save this to put on each blast record object
         """
         self._header.reference = self._value
 
     def _end_BlastOutput_db(self):
-        """the database(s) searched (PRIVATE).
+        """The database(s) searched (PRIVATE).
 
         Save this to put on each blast record object
         """
         self._header.database = self._value
 
     def _end_BlastOutput_query_ID(self):
-        """the identifier of the query (PRIVATE).
+        """The identifier of the query (PRIVATE).
 
         Important in old pre 2.2.14 BLAST, for recent versions
         <Iteration_query-ID> is enough
@@ -263,7 +274,7 @@ class BlastParser(_XMLparser):
         self._header.query_id = self._value
 
     def _end_BlastOutput_query_def(self):
-        """the definition line of the query (PRIVATE).
+        """The definition line of the query (PRIVATE).
 
         Important in old pre 2.2.14 BLAST, for recent versions
         <Iteration_query-def> is enough
@@ -271,7 +282,7 @@ class BlastParser(_XMLparser):
         self._header.query = self._value
 
     def _end_BlastOutput_query_len(self):
-        """the length of the query (PRIVATE).
+        """The length of the query (PRIVATE).
 
         Important in old pre 2.2.14 BLAST, for recent versions
         <Iteration_query-len> is enough
@@ -279,27 +290,27 @@ class BlastParser(_XMLparser):
         self._header.query_letters = int(self._value)
 
     def _end_Iteration_query_ID(self):
-        """the identifier of the query (PRIVATE)."""
+        """The identifier of the query (PRIVATE)."""
         self._blast.query_id = self._value
 
     def _end_Iteration_query_def(self):
-        """the definition line of the query (PRIVATE)."""
+        """The definition line of the query (PRIVATE)."""
         self._blast.query = self._value
 
     def _end_Iteration_query_len(self):
-        """the length of the query (PRIVATE)."""
+        """The length of the query (PRIVATE)."""
         self._blast.query_letters = int(self._value)
 
     # def _end_BlastOutput_query_seq(self):
-    #     """the query sequence (PRIVATE)."""
+    #     """The query sequence (PRIVATE)."""
     #     pass # XXX Missing in Record.Blast ?
 
     # def _end_BlastOutput_iter_num(self):
-    #     """the psi-blast iteration number (PRIVATE)."""
+    #     """The psi-blast iteration number (PRIVATE)."""
     #     pass # XXX TODO PSI
 
     def _end_BlastOutput_hits(self):
-        """hits to the database sequences, one for every sequence (PRIVATE)."""
+        """Hits to the database sequences, one for every sequence (PRIVATE)."""
         self._blast.num_hits = int(self._value)
 
     # def _end_BlastOutput_message(self):
@@ -308,11 +319,11 @@ class BlastParser(_XMLparser):
 
     # Parameters
     def _end_Parameters_matrix(self):
-        """matrix used (-M on legacy BLAST) (PRIVATE)."""
+        """Matrix used (-M on legacy BLAST) (PRIVATE)."""
         self._parameters.matrix = self._value
 
     def _end_Parameters_expect(self):
-        """expect values cutoff (PRIVATE)."""
+        """Expect values cutoff (PRIVATE)."""
         # NOTE: In old text output there was a line:
         # Number of sequences better than 1.0e-004: 1
         # As far as I can see, parameters.num_seqs_better_e
@@ -323,37 +334,37 @@ class BlastParser(_XMLparser):
         self._parameters.expect = self._value
 
     # def _end_Parameters_include(self):
-    #     """inclusion threshold for a psi-blast iteration (-h) (PRIVATE)."""
+    #     """Inclusion threshold for a psi-blast iteration (-h) (PRIVATE)."""
     #     pass # XXX TODO PSI
 
     def _end_Parameters_sc_match(self):
-        """match score for nucleotide-nucleotide comparaison (-r) (PRIVATE)."""
+        """Match score for nucleotide-nucleotide comparison (-r) (PRIVATE)."""
         self._parameters.sc_match = int(self._value)
 
     def _end_Parameters_sc_mismatch(self):
-        """mismatch penalty for nucleotide-nucleotide comparaison (-r) (PRIVATE)."""
+        """Mismatch penalty for nucleotide-nucleotide comparison (-r) (PRIVATE)."""
         self._parameters.sc_mismatch = int(self._value)
 
     def _end_Parameters_gap_open(self):
-        """gap existence cost (-G) (PRIVATE)."""
+        """Gap existence cost (-G) (PRIVATE)."""
         self._parameters.gap_penalties = int(self._value)
 
     def _end_Parameters_gap_extend(self):
-        """gap extension cose (-E) (PRIVATE)."""
+        """Gap extension cose (-E) (PRIVATE)."""
         self._parameters.gap_penalties = (self._parameters.gap_penalties,
                                          int(self._value))
 
     def _end_Parameters_filter(self):
-        """filtering options (-F) (PRIVATE)."""
+        """Filtering options (-F) (PRIVATE)."""
         self._parameters.filter = self._value
 
     # def _end_Parameters_pattern(self):
-    #     """pattern used for phi-blast search
+    #     """Pattern used for phi-blast search
     #     """
     #     pass # XXX TODO PSI
 
     # def _end_Parameters_entrez_query(self):
-    #     """entrez query used to limit search
+    #     """Entrez query used to limit search
     #     """
     #     pass # XXX TODO PSI
 
@@ -373,18 +384,18 @@ class BlastParser(_XMLparser):
         self._descr = None
 
     def _end_Hit_id(self):
-        """identifier of the database sequence (PRIVATE)."""
+        """Identifier of the database sequence (PRIVATE)."""
         self._hit.hit_id = self._value
         self._hit.title = self._value + ' '
 
     def _end_Hit_def(self):
-        """definition line of the database sequence (PRIVATE)."""
+        """Definition line of the database sequence (PRIVATE)."""
         self._hit.hit_def = self._value
         self._hit.title += self._value
         self._descr.title = self._hit.title
 
     def _end_Hit_accession(self):
-        """accession of the database sequence (PRIVATE)."""
+        """Accession of the database sequence (PRIVATE)."""
         self._hit.accession = self._value
         self._descr.accession = self._value
 
@@ -403,81 +414,81 @@ class BlastParser(_XMLparser):
 
     # Hsp_num is useless
     def _end_Hsp_score(self):
-        """raw score of HSP (PRIVATE)."""
+        """Raw score of HSP (PRIVATE)."""
         self._hsp.score = float(self._value)
         if self._descr.score is None:
             self._descr.score = float(self._value)
 
     def _end_Hsp_bit_score(self):
-        """bit score of HSP (PRIVATE)."""
+        """Bit score of HSP (PRIVATE)."""
         self._hsp.bits = float(self._value)
         if self._descr.bits is None:
             self._descr.bits = float(self._value)
 
     def _end_Hsp_evalue(self):
-        """expect value of the HSP (PRIVATE)."""
+        """Expect value of the HSP (PRIVATE)."""
         self._hsp.expect = float(self._value)
         if self._descr.e is None:
             self._descr.e = float(self._value)
 
     def _end_Hsp_query_from(self):
-        """offset of query at the start of the alignment (one-offset) (PRIVATE)."""
+        """Offset of query at the start of the alignment (one-offset) (PRIVATE)."""
         self._hsp.query_start = int(self._value)
 
     def _end_Hsp_query_to(self):
-        """offset of query at the end of the alignment (one-offset) (PRIVATE)."""
+        """Offset of query at the end of the alignment (one-offset) (PRIVATE)."""
         self._hsp.query_end = int(self._value)
 
     def _end_Hsp_hit_from(self):
-        """offset of the database at the start of the alignment (one-offset) (PRIVATE)."""
+        """Offset of the database at the start of the alignment (one-offset) (PRIVATE)."""
         self._hsp.sbjct_start = int(self._value)
 
     def _end_Hsp_hit_to(self):
-        """offset of the database at the end of the alignment (one-offset) (PRIVATE)."""
+        """Offset of the database at the end of the alignment (one-offset) (PRIVATE)."""
         self._hsp.sbjct_end = int(self._value)
 
     # def _end_Hsp_pattern_from(self):
-    #     """start of phi-blast pattern on the query (one-offset) (PRIVATE)."""
+    #     """Start of phi-blast pattern on the query (one-offset) (PRIVATE)."""
     #     pass # XXX TODO PSI
 
     # def _end_Hsp_pattern_to(self):
-    #     """end of phi-blast pattern on the query (one-offset) (PRIVATE)."""
+    #     """End of phi-blast pattern on the query (one-offset) (PRIVATE)."""
     #     pass # XXX TODO PSI
 
     def _end_Hsp_query_frame(self):
-        """frame of the query if applicable (PRIVATE)."""
+        """Frame of the query if applicable (PRIVATE)."""
         self._hsp.frame = (int(self._value),)
 
     def _end_Hsp_hit_frame(self):
-        """frame of the database sequence if applicable (PRIVATE)."""
+        """Frame of the database sequence if applicable (PRIVATE)."""
         self._hsp.frame += (int(self._value),)
 
     def _end_Hsp_identity(self):
-        """number of identities in the alignment (PRIVATE)."""
+        """Number of identities in the alignment (PRIVATE)."""
         self._hsp.identities = int(self._value)
 
     def _end_Hsp_positive(self):
-        """number of positive (conservative) substitutions in the alignment (PRIVATE)."""
+        """Number of positive (conservative) substitutions in the alignment (PRIVATE)."""
         self._hsp.positives = int(self._value)
 
     def _end_Hsp_gaps(self):
-        """number of gaps in the alignment (PRIVATE)."""
+        """Number of gaps in the alignment (PRIVATE)."""
         self._hsp.gaps = int(self._value)
 
     def _end_Hsp_align_len(self):
-        """length of the alignment (PRIVATE)."""
+        """Length of the alignment (PRIVATE)."""
         self._hsp.align_length = int(self._value)
 
     # def _en_Hsp_density(self):
-    #     """score density (PRIVATE)."""
+    #     """Score density (PRIVATE)."""
     #     pass # XXX ???
 
     def _end_Hsp_qseq(self):
-        """alignment string for the query (PRIVATE)."""
+        """Alignment string for the query (PRIVATE)."""
         self._hsp.query = self._value
 
     def _end_Hsp_hseq(self):
-        """alignment string for the database (PRIVATE)."""
+        """Alignment string for the database (PRIVATE)."""
         self._hsp.sbjct = self._value
 
     def _end_Hsp_midline(self):
@@ -488,19 +499,19 @@ class BlastParser(_XMLparser):
 
     # Statistics
     def _end_Statistics_db_num(self):
-        """number of sequences in the database (PRIVATE)."""
+        """Number of sequences in the database (PRIVATE)."""
         self._blast.num_sequences_in_database = int(self._value)
 
     def _end_Statistics_db_len(self):
-        """number of letters in the database (PRIVATE)."""
+        """Number of letters in the database (PRIVATE)."""
         self._blast.num_letters_in_database = int(self._value)
 
     def _end_Statistics_hsp_len(self):
-        """the effective HSP length (PRIVATE)."""
+        """The effective HSP length (PRIVATE)."""
         self._blast.effective_hsp_length = int(self._value)
 
     def _end_Statistics_eff_space(self):
-        """the effective search space (PRIVATE)."""
+        """The effective search space (PRIVATE)."""
         self._blast.effective_search_space = float(self._value)
 
     def _end_Statistics_kappa(self):
@@ -644,32 +655,3 @@ def parse(handle, debug=0):
     assert text == ""
     assert pending == ""
     assert len(blast_parser._records) == 0
-
-if __name__ == '__main__':
-    import sys
-    with open(sys.argv[1]) as handle:
-        r_list = parse(handle)
-
-    for r in r_list:
-        # Small test
-        print('Blast of %s' % r.query)
-        print('Found %s alignments with a total of %s HSPs'
-                  % (len(r.alignments),
-                     reduce(lambda a, b: a + b,
-                            [len(a.hsps) for a in r.alignments])))
-
-        for al in r.alignments:
-            print("%s %i bp %i HSPs" % (al.title[:50], al.length, len(al.hsps)))
-
-        # Cookbook example
-        E_VALUE_THRESH = 0.04
-        for alignment in r.alignments:
-            for hsp in alignment.hsps:
-                if hsp.expect < E_VALUE_THRESH:
-                    print('*****')
-                    print('sequence %s' % alignment.title)
-                    print('length %i' % alignment.length)
-                    print('e value %f' % hsp.expect)
-                    print(hsp.query[:75] + '...')
-                    print(hsp.match[:75] + '...')
-                    print(hsp.sbjct[:75] + '...')
